@@ -55,6 +55,10 @@
 #include "dds_tape.h"
 #include "zf-cre-open.h"
 
+#ifndef VENDOR
+#define VENDOR HP
+#endif
+
 /*-------------------------------------------------------------------------*/
 
 static const char help_text_dds2index[] =
@@ -65,6 +69,9 @@ static const char help_text_dds2index[] =
 "--z,--no-compress       don't filter location file through gzip\n"
 "-f,--device F           read the archive from device F\n"
 "-b,--block-size #       set block size\n"
+#if VENDOR == HP
+"-B,--Block-size #       set block size of the device\n"
+#endif
 "-q,--quick              don't extract parent directories from tape\n"
 "-v,--verbose            verbose mode\n"
 "--hash-mode             hash mode\n"
@@ -93,6 +100,9 @@ static const char help_text_dds2tar[] =
 "-f,--device F           read the archive from device F\n"
 "-o,--output F           write output to archive file\n"
 "-b,--block-size #       set block size\n"
+#if VENDOR == HP
+"-B,--Block-size #       set block size of the device\n"
+#endif
 "-s,--first_block #      set number of the first block\n"
 "--body                  print only the contents of the first file an quit\n"
 "-v,--verbose            verbose mode\n"
@@ -118,13 +128,15 @@ static const char help_text_mt_dds[] =
 #endif
 "-b           set the buffer size\n"
 "blksize      print the block size of the archive with format\n"
-"tell         print current location\n"
+"tell         print current location and blocksize\n"
+"where        print current location\n"
 "label        print the label of the current archive\n"
 "             if it begins at the current position\n"
 "filename     print the filename of the current record\n"
 "             if a header record is found at the current position\n"
 "ts           print the timestamp of the current archive\n"
 "date         print the date of the current archive\n"
+"scsi2logical select mode scsi2logical first\n"
 "             if it begins at the current position\n"
 "date <timestamp> convert the stamp to a string\n"
        ;
@@ -343,6 +355,9 @@ main(int argc, char const *const *argv)
 #define DEVICE "/dev/rmt0"
 #endif
 
+#if VENDOR == HP
+	int	density = 0 ;
+#endif
 	int     n = 1;
 	int     l = strlen(argv[0]);
 	int     compressed_mode = T_MODE;
@@ -394,6 +409,14 @@ main(int argc, char const *const *argv)
 			tar_n = tar_bs * 512;
 			buf_n = tar_n ;
 			p += count;
+#if VENDOR == HP
+		} else if (strprefix(&p, "--Block-size ","-B ")){
+			sscanf(p, "%d%n", &tar_bs, &count);
+			tar_n = tar_bs * 512;
+			buf_n = tar_n ;
+			p += count;
+			density = tar_n ;
+#endif
 		} else
 			p = NULL;
 	}
@@ -469,6 +492,14 @@ main(int argc, char const *const *argv)
 			tar_n = tar_bs * 512;
 			buf_n = tar_n ;
 		}
+#if VENDOR == HP
+		TT("-B", "--Block-size") {
+			tar_bs = atoi(argv[++n]);
+			tar_n = tar_bs * 512;
+			buf_n = tar_n ;
+			density = tar_n ;
+		}
+#endif
 		TT("-m", "--buffer-size") {
 			fprintf(stderr,"buffer size is %d records, %d bytes\n",
 				buf_n>>9,buf_n);
@@ -543,7 +574,6 @@ main(int argc, char const *const *argv)
 			TT("-q","--quick"){
 				quick_mode = 1 ;
 			}
-
 			/*
 			 * Pipe the output to tar -x.
 			 *
@@ -630,6 +660,16 @@ main(int argc, char const *const *argv)
 				R("comp-unload");
 				mt_action = DDSCM_UNLOAD;
 			}
+			T("where") {
+				mt_action = DDSCM_WHERE;
+			}
+			/*
+			 * Set mode scsi2logical first
+			 */
+			T("scsi2logical"){
+				mt_action = DDSCM_LOGICAL;
+			}
+
 #endif
 #ifdef EXP_STUFF
 			/*
@@ -666,7 +706,16 @@ main(int argc, char const *const *argv)
 		 */
 		if (mt_action != DDSCM_NULL) {
 			device = open_device(device_name, O_WRONLY);
-			set_compression_mode(device, mt_action);
+			if ( mt_action == DDSCM_LOGICAL )
+				dds_scsi2logical();
+			else
+			if ( mt_action == DDSCM_WHERE ) {
+				tar_fb = dds_getpos(device);
+				printf(" -s %d \n", tar_fb);
+				close(device);
+				return 0;
+			} else
+				set_compression_mode(device, mt_action);
 		} else
 #endif
 		/*
@@ -719,8 +768,14 @@ main(int argc, char const *const *argv)
 
 		if (pattern_list == NULL)
 			return 0;
-		if (list_only != 1)
+		if (list_only != 1) {
 			device = open_device(device_name, O_RDONLY);
+#if VENDOR != HP
+			dds_set_bs(tar_n);
+#else
+			if ( density ) dds_set_bs(density);
+#endif
+		}
 		index_fp = zfopen(index_file, compressed_mode, "r");
 		switch (mode) {
 #ifdef EXP_STUFF
@@ -741,12 +796,18 @@ main(int argc, char const *const *argv)
 		/*---------------------DDS2INDEX-----------------------------*/
 	} else if (pg == DDS2INDEX) {
 		device = open_device(device_name, O_RDONLY);
+#if VENDOR != HP
+		dds_set_bs(tar_n);
+#endif
 		index_fp = zfopen(index_file, compressed_mode, "w");
 		dds_index();
 		close(device);
 		/*-----------------------------------------------------------*/
 	} else if ( pg == DDS_DD ) {
 		device = open_device(device_name, O_RDONLY);
+#if VENDOR != HP
+		dds_set_bs(tar_n);
+#endif
 		if ( verbose ) fprintf(stderr,"dds-dd ...\n");
 		while ( dds_read_next_block() , cur_n )
 			fwrite(cur_block,1,cur_n,stdout);
