@@ -4,6 +4,7 @@
  * Copyright by J"org Weule
  */
 
+extern int dds_scsi2logical(void);
 extern int dds_bsr(void);
 extern void dds_read_block(void);
 extern void dds_read_next_block(void);
@@ -18,6 +19,8 @@ extern int dds_seek(int const dev ,int const blkno);
 #define DDSCM_LOAD 4
 #define DDSCM_UNLOAD 5
 #define DDSCM_FILENO 6
+#define DDSCM_LOGICAL 7
+#define DDSCM_WHERE 8
 
 extern void set_compression_mode(int _device, const int _mode);
 
